pycocoa.sets.FrozenSet

Package pycocoa :: Module sets :: Class FrozenSet |
[frames] | no frames]

# Class FrozenSet

      object --+
               |
       frozenset --+
                   |
      object --+   |
               |   |
    bases._Type0 --+
                   |
                  FrozenSet

Python `frozenset` Type, wrapping an immutable ObjC `NSSet`.

Instance Methods
__init__(self, ns_set=()) New FrozenSet from a `frozenset`, `list`, `set`, `tuple`, FrozenSet, Set or `NSSet`. |
__contains__(self, elem) y in x. |
__and__(self, elem) x&y |
__cmp__(self, elem) cmp(x,y) |
__eq__(self, elem) x==y |
__ge__(self, elem) x>=y |
__gt__(self, elem) x>y |
__iter__(self) iter(x) |
__len__(self) len(x) |
__lt__(self, elem) x<y |
__ne__(self, elem) x!=y |
__rand__(self, elem) y&x |
__ror__(self, elem) y|x |
__rsub__(self, elem) y-x |
__rxor__(self, elem) y^x |
size of S in memory, in bytes |
__sizeof__(self, elem) size of object in memory, in bytes |
__sub__(self, elem) x-y |
__xor__(self, elem) x^y |
copy(self) Make a copy of this frozen set. |
difference(self, *others) Like `frozen/set.difference`. |
intersection(self, *others) Like `frozen/set.intersection`. |
isdisjoint(self, other) Like `frozen/set.isdisjoint`. |
issubset(self, other) Like `frozen/set.issubset`. |
issuperset(self, other) Like `frozen/set.issuperset`. |
symmetric_difference(self, other) Like `frozen/set.symmetric_difference`. |
union(self, *others) Like `frozen/set.union`. |
Inherited from `frozenset`: `__getattribute__`, `__hash__`, `__le__`, `__or__`, `__reduce__`, `__repr__` Inherited from `bases._Type0`: `__str__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__reduce_ex__`, `__setattr__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, ns_frozenset=`(``)`) New FrozenSet from a `frozenset`, `list`, `set`, `tuple`, FrozenSet or `NSSet`. |

Properties
| NS Get the ObjC instance (`NSSet`).
Inherited from `bases._Type0`: `NSDelegate` Inherited from `object`: `__class__`

Method Details

### __init__(self, ns_set=()) (Constructor) |
New FrozenSet from a `frozenset`, `list`, `set`, `tuple`, FrozenSet, Set or `NSSet`. Overrides: object.__init__

### __contains__(self, elem) (In operator) |
y in x. Overrides: frozenset.__contains__ (inherited documentation)

### __and__(self, elem) (And operator) |
x&y Overrides: frozenset.__and__ (inherited documentation)

### __cmp__(self, elem) (Comparison operator) |
cmp(x,y) Overrides: frozenset.__cmp__ (inherited documentation)

### __eq__(self, elem) (Equality operator) |
x==y Overrides: frozenset.__eq__ (inherited documentation)

### __ge__(self, elem) (Greater-than-or-equals operator) |
x>=y Overrides: frozenset.__ge__ (inherited documentation)

### __gt__(self, elem) (Greater-than operator) |
x>y Overrides: frozenset.__gt__ (inherited documentation)

### __iter__(self) |
iter(x) Overrides: frozenset.__iter__ (inherited documentation)

### __len__(self) (Length operator) |
len(x) Overrides: frozenset.__len__ (inherited documentation)

### __lt__(self, elem) (Less-than operator) |
x<y Overrides: frozenset.__lt__ (inherited documentation)

### __ne__(self, elem) |
x!=y Overrides: frozenset.__ne__ (inherited documentation)

### __rand__(self, elem) |
y&x Overrides: frozenset.__rand__ (inherited documentation)

### __ror__(self, elem) |
y|x Overrides: frozenset.__ror__ (inherited documentation)

### __rsub__(self, elem) |
y-x Overrides: frozenset.__rsub__ (inherited documentation)

### __rxor__(self, elem) |
y^x Overrides: frozenset.__rxor__ (inherited documentation)

### __sizeof__(self, elem) |
size of object in memory, in bytes Returns: size of S in memory, in bytes Overrides: object.__sizeof__ (inherited documentation)

### __sub__(self, elem) (Subtraction operator) |
x-y Overrides: frozenset.__sub__ (inherited documentation)

### __xor__(self, elem) (Exclusive-Or operator) |
x^y Overrides: frozenset.__xor__ (inherited documentation)

### copy(self) |
Make a copy of this frozen set. Returns: The copy (FrozenSet). Overrides: frozenset.copy

### difference(self, *others) |
Like `frozen/set.difference`. Returns: New instance (FrozenSet or Set). Overrides: frozenset.difference

### intersection(self, *others) |
Like `frozen/set.intersection`. Returns: New instance (FrozenSet or Set). Overrides: frozenset.intersection

### isdisjoint(self, other) |
Like `frozen/set.isdisjoint`. Overrides: frozenset.isdisjoint

### issubset(self, other) |
Like `frozen/set.issubset`. Overrides: frozenset.issubset

### issuperset(self, other) |
Like `frozen/set.issuperset`. Overrides: frozenset.issuperset

### symmetric_difference(self, other) |
Like `frozen/set.symmetric_difference`. Returns: New instance (FrozenSet or Set). Overrides: frozenset.symmetric_difference

### union(self, *others) |
Like `frozen/set.union`. Returns: New instance (FrozenSet or Set). Overrides: frozenset.union

### __new__(cls, ns_frozenset=`(``)`) Static Method |
New FrozenSet from a `frozenset`, `list`, `set`, `tuple`, FrozenSet or `NSSet`. Returns: a new object with type S, a subtype of T Overrides: object.__new__

Property Details

### NS Get the ObjC instance (`NSSet`). Get Method: NS(self) - Get the ObjC instance (`NSSet`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.